Learn R Programming

mAPKL (version 1.0.0)

netwAttr: Calculates network characteristics

Description

Calculate some basic network characteristics of the top ranked genes

Usage

netwAttr(mAPKLObj)

Arguments

mAPKLObj
An object of mAPKL class.

Value

Upon successful completion, the function returns an NetAttr object.

Details

It calculates some basic network characteristics. Those include the "degree", the "closeness", the "betweenness", and finally the "transitivity" or else clustering coefficient. We calculate the weighted values for both local and global scores.

Examples

Run this code
library(mAPKLData)
data(mAPKLData)
breast <- sampling(Data=mAPKLData, valPercent=40, classLabels="type", seed=135)
normTrainData <- preprocess(breast$trainData)
normTestData <- preprocess(breast$testData)

exprs(breast$trainData) <- normTrainData$clL2.normdata
exprs(breast$testData) <- normTestData$clL2.normdata

out.clL2 <- mAPKL(trObj=breast$trainData, classLabels="type",
valObj=breast$testData, dataType=7)

net.attr <- netwAttr(mAPKLObj=out.clL2)

Run the code above in your browser using DataLab